@@ -19,6 +19,7 @@ from suite_py.commands.open_pr import OpenPR
 from suite_py.commands.project_lock import ProjectLock
 from suite_py.commands.rollback import Rollback
 from suite_py.commands.status import Status
+from suite_py.commands.aggregator import Aggregator
 from suite_py.lib.config import Config
 from suite_py.lib.handler import git_handler as git
 from suite_py.lib.handler import prompt_utils
@@ -160,3 +161,11 @@ def cli_ip(obj, environment):
 @click.pass_obj
 def cli_generator(obj):
     Generator(obj["config"], obj["tokens"]).run()
+
+
+@main.command("aggregator", help="Gestione dei puntamenti dai vari aggregatori ai QA")
+@click.option("-l", "--list", "show_list", required=False, count=True)
+@click.option("-c", "--change", "change", required=False, count=True)
+@click.pass_obj
+def cli_aggregator(obj, show_list, change):
+    Aggregator(obj["config"], show_list, change).run()
