@@ -90,15 +90,18 @@ class DroneHandler:
         attempts = 0
         while attempts < 3:
 
-            builds = requests.get(
-                f"{BASEURL}/api/repos/primait/{self._repo}/builds?per_page=100",
-                headers={"Authorization": f"Bearer {self._token}"},
-            ).json()
+            try:
+                builds = requests.get(
+                    f"{BASEURL}/api/repos/primait/{self._repo}/builds?per_page=100",
+                    headers={"Authorization": f"Bearer {self._token}"},
+                ).json()
 
-            for build in builds:
-                if build["event"] == "tag":
-                    if build["ref"].replace("refs/tags/", "") == tag:
-                        return build["number"]
+                for build in builds:
+                    if build["event"] == "tag":
+                        if build["ref"].replace("refs/tags/", "") == tag:
+                            return build["number"]
+            except Exception:
+                pass
 
             time.sleep(2)
             attempts += 1
